<?php

namespace Drupal\aimtell\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure AimTell settings.
 */
class AimTellSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'aimtell_config';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('aimtell.settings');

    $form['domain'] = [
      '#title' => 'Site hostname',
      '#type' => 'textfield',
      '#maxlength' => 255,
      '#default_value' => $config->get('domain'),
      '#description' => t('The full hostname of the website. Do not include the "http://" or "https://" portion.'),
      '#required' => TRUE,
    ];

    $form['owner'] = [
      '#title' => 'Site owner',
      '#type' => 'textfield',
      '#maxlength' => 255,
      '#default_value' => $config->get('owner'),
      '#description' => t('The alphanumerical site owner ID.'),
      '#required' => TRUE,
    ];

    $form['site_id'] = [
      '#title' => 'Site ID',
      '#type' => 'textfield',
      '#maxlength' => 255,
      '#default_value' => $config->get('site_id'),
      '#description' => t('The numerical site ID.'),
      '#required' => TRUE,
    ];

    $form['webpush_id'] = [
      '#title' => 'Web Push ID',
      '#type' => 'textfield',
      '#maxlength' => 255,
      '#default_value' => $config->get('webpush_id'),
      '#description' => t('The hostname that will be used, e.g. "web.70.aimtell.com".'),
      '#required' => TRUE,
    ];

    $form['enable_branding'] = [
      '#title' => 'AimTell branding',
      '#type' => 'checkbox',
      '#default_value' => $config->get('enable_branding'),
      '#description' => t('Enable "Powered by Aimtell" message in console'),
    ];

    $form['enable'] = [
      '#title' => 'Enable',
      '#type' => 'checkbox',
      '#default_value' => $config->get('enable'),
      '#description' => t('Enable AimTell'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('aimtell.settings')
      ->set('domain', $form_state->getValue('domain'))
      ->set('owner', $form_state->getValue('owner'))
      ->set('site_id', $form_state->getValue('site_id'))
      ->set('webpush_id', $form_state->getValue('webpush_id'))
      ->set('enable_branding', $form_state->getValue('enable_branding'))
      ->set('enable', $form_state->getValue('enable'))
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['aimtell.settings'];
  }

}
